float blend;
float desat;
float toned;
float3 lightColor;
float3 darkColor;
float radialLimit;
float time_0_x;
sampler RT: register(s0);
sampler BlipsSampler: register(s1);
sampler ScratchSampler: register(s2);
float4 main_ps(float2 UV0: TEXCOORD0, float2 UV1: TEXCOORD1, float2 UV2: TEXCOORD2) : COLOR
{
	// Calculate brightness
	float3 origScnColor = tex2D(RT, UV0).xyz;
	float brightness = 3.0 * sin(time_0_x * 1.5);
	brightness = clamp(brightness, 0.8, 1.0);

	// Determine sepia color
	float3 scnColor = lightColor * origScnColor;
	float3 grayXfer = float3(0.3,0.59,0.11);
	float gray = dot(grayXfer, scnColor);
	float3 muted = lerp(scnColor, gray.xxx, desat);
	float3 sepia = lerp(darkColor, lightColor, gray);
	sepia = lerp(muted, sepia, toned);

	// Get the blibs and scratches
	float3 blibColor = tex2D(BlipsSampler, UV1).xyz;
	float3 scratchColor = tex2D(ScratchSampler, UV2).xyz;

	// Fade the edges
	float xDiff = (UV0.x - 0.5);
	float yDiff = (UV0.y - 0.5);
	float distSquared = xDiff * xDiff + yDiff * yDiff;
	float4 edgeColor = smoothstep(radialLimit, 0.0, distSquared);

	// Apply blending
	origScnColor *= (1-blend);
	sepia *= blend;
	float3 col = blend * blibColor * scratchColor;
	return saturate((1-blend) * float4(origScnColor.xyz, 1) + brightness * float4(sepia.xyz, 1) * float4(col.xyz, 1) * edgeColor);
}
